@@ -125,37 +125,39 @@ PSPMecodyn <- function(modelname = NULL, startstate = NULL, timepars = NULL, bif
 
   pkgmodeldir <- system.file("Models", package="PSPManalysis")
   modelfound <- 0
-  for (modeldir in c(".", pkgmodeldir))
+  modeldname <- dirname(modelname)
+  modelbname <- basename(modelname)
+  for (modeldir in c(modeldname, pkgmodeldir))
     {
       if (modeldir == pkgmodeldir)
         {
           str <- readline(paste0("\nModel file not found in current directory\nContinue searching for model file in package directory? [y(es)/q(uit)] : "))
           if ((str != '') && (str != 'y') && (str != 'Y')) break
         }
-      if ((regexpr("\\.h", modelname) == (nchar(modelname)-1)) && file.exists(paste0(modeldir, "/", modelname)))
+      if ((regexpr("\\.h", modelbname) == (nchar(modelbname)-1)) && file.exists(paste0(modeldir, "/", modelbname)))
         {
-          hfile.fullname <- paste0(modeldir, "/", modelname)
+          hfile.fullname <- paste0(modeldir, "/", modelbname)
           rmodel <- 0
           modelfound <- 1
           break
         }
-      if ((regexpr("\\.R", modelname) == (nchar(modelname)-1)) && file.exists(paste0(modeldir, "/", modelname)))
+      if ((regexpr("\\.R", modelbname) == (nchar(modelbname)-1)) && file.exists(paste0(modeldir, "/", modelbname)))
         {
-          hfile.fullname <- paste0(modeldir, "/", modelname)
+          hfile.fullname <- paste0(modeldir, "/", modelbname)
           rmodel <- 1
           modelfound <- 1
           break
         }
-      if (file.exists(paste0(modeldir, "/", modelname, ".h")))
+      if (file.exists(paste0(modeldir, "/", modelbname, ".h")))
         {
-          hfile.fullname <- paste0(modeldir, "/", modelname, ".h")
+          hfile.fullname <- paste0(modeldir, "/", modelbname, ".h")
           rmodel <- 0
           modelfound <- 1
           break
         }
-      if (file.exists(paste0(modeldir, "/", modelname, ".R")))
+      if (file.exists(paste0(modeldir, "/", modelbname, ".R")))
         {
-          hfile.fullname <- paste0(modeldir, "/", modelname, ".R")
+          hfile.fullname <- paste0(modeldir, "/", modelbname, ".R")
           rmodel <- 1
           modelfound <- 1
           break
@@ -313,13 +315,13 @@ PSPMecodyn <- function(modelname = NULL, startstate = NULL, timepars = NULL, bif
     if (ImpactDimension < 1) stop(paste0("INTERACT_DIM equals ", ImpactDimension, ", but should be larger than 0!\n\n"))
 
     # Construct the command line
-    buildargs <- paste0("--output=\'", libfile.basename, "\'")
-    buildargs <- paste(buildargs, "PSPMecodyn.c ebtcohrt.c ebtdopri5.c ebtutils.c", sep=" ")
+    buildargs <- c(paste0("--output=\'", libfile.basename, "\'"), "PSPMecodyn.c", "ebtcohrt.c", "ebtdopri5.c", "ebtutils.c")
 
     # Define the basic compilation flags
     cppflags <- "-DR_PACKAGE"
     if (exists("CFLAGS")) cppflags <- paste0(cppflags, " ", get("CFLAGS"))
     if (debug) cppflags <- paste0(cppflags, " -DDEBUG=1 -g -Wall")
+    else cppflags <- paste0(cppflags, " -Wno-format-overflow")
     cppflags <- paste0(cppflags, " -I.", " -I\"", PSPMsrcdir.name, "\" -I\"", PSPMsrcdir.name, "/escbox\" ")
 
     hasfftw <- FALSE
@@ -346,8 +348,8 @@ PSPMecodyn <- function(modelname = NULL, startstate = NULL, timepars = NULL, bif
       }
     }
     
-    if (hasfftw) buildenv <- c(PKG_CPPFLAGS = paste(cppflags, modelflags), PKG_LIBS = "-lm $(FFTW3_LIBS)")
-    else buildenv <- c(PKG_CPPFLAGS = paste(cppflags, modelflags), PKG_LIBS = "-lm")
+    if (hasfftw) buildenv <- c(PKG_CFLAGS = paste(cppflags, modelflags), PKG_LIBS = "-lm $(FFTW3_LIBS)")
+    else buildenv <- c(PKG_CFLAGS = paste(cppflags, modelflags), PKG_LIBS = "-lm")
 
     if (debug) {
       cat("Current working directory: ", getwd(), "\n")
@@ -407,7 +409,7 @@ PSPMecodyn <- function(modelname = NULL, startstate = NULL, timepars = NULL, bif
     output <- list(curvedesc = desc, curvepoints = data)
     return(output)
   }
-  else return
+  else return()
 }
 
 
